

set -ex



x86_64-conda_cos6-linux-gnu-addr2line --help
x86_64-conda_cos6-linux-gnu-ar --help
x86_64-conda_cos6-linux-gnu-as --help
x86_64-conda_cos6-linux-gnu-c++filt --help
x86_64-conda_cos6-linux-gnu-elfedit --help
x86_64-conda_cos6-linux-gnu-gprof --help
x86_64-conda_cos6-linux-gnu-ld --help
x86_64-conda_cos6-linux-gnu-ld.bfd --help
x86_64-conda_cos6-linux-gnu-ld.gold --help
x86_64-conda_cos6-linux-gnu-nm --help
x86_64-conda_cos6-linux-gnu-objcopy --help
x86_64-conda_cos6-linux-gnu-objdump --help
x86_64-conda_cos6-linux-gnu-ranlib --help
x86_64-conda_cos6-linux-gnu-readelf --help
x86_64-conda_cos6-linux-gnu-size --help
x86_64-conda_cos6-linux-gnu-strings --help
x86_64-conda_cos6-linux-gnu-strip --help
echo 7.3.0
exit 0
